package com.me.asteroids.systems;

import com.badlogic.gdx.math.Rectangle;
import com.me.asteroids.components.ModelComponent;
import com.me.asteroids.events.CollisionEvent;
import com.me.common.ecs.ComponentMapper;
import com.me.common.ecs.Engine;
import com.me.common.ecs.Entity;
import com.me.common.ecs.EntitySystem;

public class CollisionSystem extends EntitySystem {

    private ComponentMapper<ModelComponent> modelMapper;

    public CollisionSystem(Engine engine) {
        super(engine, ModelComponent.class);
        modelMapper = engine.getComponentMapper(ModelComponent.class);
    }

    @Override
    public void process(float dt) {
        Entity[] entities = getEntities().items;
        for (int i = 0, n = getEntities().size; i < n-1; i++) {
            Entity entityA = entities[i];
            Rectangle aabbA = modelMapper.get(entityA).aabb;

            for (int j = i + 1; j < n; j++) {
                Entity entityB = entities[j];

                Rectangle aabbB = modelMapper.get(entityB).aabb;
                if (aabbA.overlaps(aabbB)) {
                    CollisionEvent event = new CollisionEvent(entityA, entityB);
                    engine.callEvent(event);
                }
            }
        }
    }

    @Override
    public void processEntity(Entity entity, float dt) {}

}
